@@ -12,6 +12,9 @@ sub init_edit_disp_remote {
     $gui{entryEditDispBind}->set_text(IVRDEServer_getVRDEProperty($vmc{IVRDEServer}, 'TCP/Address'));
     $gui{checkbuttonEditDispMultiple}->set_active(&bl(IVRDEServer_getAllowMultiConnection($vmc{IVRDEServer})));
     &combobox_set_active_text($gui{comboboxDispAuthMeth}, IVRDEServer_getAuthType($vmc{IVRDEServer}), 0);
+    # FIXME: Forced at the moment
+    IVRDEServer_setVRDEProperty($vmc{IVRDEServer}, 'Security/Method', 'NEGOTIATE');
+    IVRDEServer_setVRDEProperty($vmc{IVRDEServer}, 'Security/ServerCertificate', '');
     &set_pointer($gui{dialogEdit});
 }
 
