@@ -260,8 +260,8 @@ sub get_icontroller_attrs {
 {
     my @rdp_preset_tbl = ({num => 1, desc => 'FreeRDP',                    command => 'xfreerdp /size:%Xx%Y /bpp:32 +clipboard /sound /t:"%n - RemoteBox" /v:%h:%p /d: /p: /cert:ignore'},
                           {num => 2, desc => 'FreeRDP (Old Syntax)',       command => 'xfreerdp -g %Xx%Y --plugin cliprdr --plugin rdpsnd -T "%n - RemoteBox" %h:%p'},
-                          {num => 3, desc => 'Remmina',                    command => 'remmina rdp://%h:%p'},
-                          {num => 4, desc => 'Rdesktop',                   command => 'rdesktop -g %Xx%Y -r sound:local -r clipboard:PRIMARYCLIPBOARD -T "%n - RemoteBox" %h:%p -I'},
+                          {num => 3, desc => 'Remmina',                    command => 'remmina rdp://%U@%h:%p'},
+                          {num => 4, desc => 'Rdesktop',                   command => 'rdesktop -g %Xx%Y -r sound:local -r clipboard:PRIMARYCLIPBOARD -T "%n - RemoteBox" %h:%p'},
                           {num => 5, desc => 'KRDC',                       command => 'krdc rdp://%h:%p'},
                           {num => 6, desc => 'Windows RDP Client (mstsc)', command => 'mstsc /w:%X /h:%Y /v:%h:%p'});
 
