@@ -81,7 +81,11 @@ sub show_dialog_new_guest {
                     IMachine_setClipboardMode($IMachine, 'Bidirectional');
 
                     if ($$vhost{vrdeextpack} =~ m/vnc/i) { IVRDEServer_setVRDEProperty($IVRDEServer, 'TCP/Ports', $prefs{DEFVNCPORTS}) }
-                    else { IVRDEServer_setVRDEProperty($IVRDEServer, 'TCP/Ports', $prefs{DEFRDPPORTS}); }
+                    else {
+                        IVRDEServer_setVRDEProperty($IVRDEServer, 'TCP/Ports', $prefs{DEFRDPPORTS});
+                        IVRDEServer_setVRDEProperty($IVRDEServer, 'Security/Method', 'NEGOTIATE');
+                        IVRDEServer_setVRDEProperty($IVRDEServer, 'Security/ServerCertificate', '');
+                    }
 
                     IMachine_saveSettings($IMachine);
                     IVirtualBox_registerMachine($gui{websn}, $IMachine);
